@@ -11,7 +11,7 @@ import requests
 
 from ... import service
 from ..._compat import metadata
-from ...constants import DISCORD_LINK, CodeSampleStyle, __version__
+from ...constants import DISCORD_LINK, FLAKY_FAILURE_MESSAGE, CodeSampleStyle, __version__
 from ...models import Response, Status
 from ...runner import events
 from ...runner.serialization import SerializedCase, SerializedError, SerializedTestResult, deduplicate_failures
@@ -55,9 +55,12 @@ def get_percentage(position: int, length: int) -> str:
 
 def display_execution_result(context: ExecutionContext, event: events.AfterExecution) -> None:
     """Display an appropriate symbol for the given event's execution result."""
-    symbol, color = {Status.success: (".", "green"), Status.failure: ("F", "red"), Status.error: ("E", "red")}[
-        event.status
-    ]
+    symbol, color = {
+        Status.success: (".", "green"),
+        Status.failure: ("F", "red"),
+        Status.error: ("E", "red"),
+        Status.skip: ("S", "yellow"),
+    }[event.status]
     context.current_line_length += len(symbol)
     click.secho(symbol, nl=False, fg=color)
 
@@ -90,6 +93,9 @@ def get_summary_message_parts(event: events.Finished) -> List[str]:
     errored = event.errored_count
     if errored:
         parts.append(f"{errored} errored")
+    skipped = event.skipped_count
+    if skipped:
+        parts.append(f"{skipped} skipped")
     return parts
 
 
@@ -102,6 +108,8 @@ def get_summary_output(event: events.Finished) -> Tuple[str, str]:
         message = f'{", ".join(parts)} in {event.running_time:.2f}s'
         if event.has_failures or event.has_errors:
             color = "red"
+        elif event.skipped_count > 0:
+            color = "yellow"
         else:
             color = "green"
     return message, color
@@ -193,6 +201,9 @@ def display_failures(context: ExecutionContext, event: events.Finished) -> None:
 def display_failures_for_single_test(context: ExecutionContext, result: SerializedTestResult) -> None:
     """Display a failure for a single method / path."""
     display_subsection(result)
+    if result.is_flaky:
+        click.secho(FLAKY_FAILURE_MESSAGE, fg="red")
+        click.echo()
     checks = deduplicate_failures(result.checks)
     for idx, check in enumerate(checks, 1):
         message: Optional[str]
