@@ -83,9 +83,12 @@ class CaseSource:
 
     case: "Case" = attr.ib()  # pragma: no mutate
     response: GenericResponse = attr.ib()  # pragma: no mutate
+    elapsed: float = attr.ib()  # pragma: no mutate
 
     def partial_deepcopy(self) -> "CaseSource":
-        return self.__class__(case=self.case.partial_deepcopy(), response=copy_response(self.response))
+        return self.__class__(
+            case=self.case.partial_deepcopy(), response=copy_response(self.response), elapsed=self.elapsed
+        )
 
 
 def cant_serialize(media_type: str) -> NoReturn:  # type: ignore
@@ -154,8 +157,8 @@ class Case:  # pylint: disable=too-many-public-methods
     def app(self) -> Any:
         return self.operation.app
 
-    def set_source(self, response: GenericResponse, case: "Case") -> None:
-        self.source = CaseSource(case=case, response=response)
+    def set_source(self, response: GenericResponse, case: "Case", elapsed: float) -> None:
+        self.source = CaseSource(case=case, response=response, elapsed=elapsed)
 
     @property
     def formatted_path(self) -> str:
@@ -278,12 +281,13 @@ class Case:  # pylint: disable=too-many-public-methods
     def _get_serializer(self) -> Optional[Serializer]:
         """Get a serializer for the payload, if there is any."""
         if self.media_type is not None:
-            cls = serializers.get(self.media_type)
-            if cls is None:
-                all_media_types = self.operation.get_request_payload_content_types()
-                if all(serializers.get(media_type) is None for media_type in all_media_types):
-                    raise SerializationNotPossible.from_media_types(*all_media_types)
-                cant_serialize(self.media_type)
+            media_type = serializers.get_first_matching_media_type(self.media_type)
+            if media_type is None:
+                # This media type is set manually. Otherwise, it should have been rejected during the data generation
+                raise SerializationNotPossible.for_media_type(self.media_type)
+            # SAFETY: It is safe to assume that serializer will be found, because `media_type` returned above
+            # is registered. This intentionally ignores cases with concurrent serializers registry modification.
+            cls = cast(Type[serializers.Serializer], serializers.get(media_type))
             return cls()
         return None
 
@@ -958,6 +962,7 @@ class TestResult:
     is_errored: bool = attr.ib(default=False)  # pragma: no mutate
     is_flaky: bool = attr.ib(default=False)  # pragma: no mutate
     is_skipped: bool = attr.ib(default=False)  # pragma: no mutate
+    is_executed: bool = attr.ib(default=False)  # pragma: no mutate
     seed: Optional[int] = attr.ib(default=None)  # pragma: no mutate
     # To show a proper reproduction code if an error happens and there is no way to get actual headers that were
     # sent over the network. Or there could be no actual requests at all
@@ -972,6 +977,9 @@ class TestResult:
     def mark_skipped(self) -> None:
         self.is_skipped = True
 
+    def mark_executed(self) -> None:
+        self.is_executed = True
+
     @property
     def has_errors(self) -> bool:
         return bool(self.errors)
