@@ -7,6 +7,7 @@ import jsonschema
 import requests
 import yaml
 
+from ...constants import DEFAULT_RESPONSE_TIMEOUT
 from ...utils import StringDatesYAMLLoader
 from .converter import to_json_schema_recursive
 
@@ -34,10 +35,13 @@ def load_file_uri(location: str) -> Dict[str, Any]:
 
 def load_remote_uri(uri: str) -> Any:
     """Load the resource and parse it as YAML / JSON."""
-    response = requests.get(uri)
+    response = requests.get(uri, timeout=DEFAULT_RESPONSE_TIMEOUT / 1000)
     return yaml.load(response.content, StringDatesYAMLLoader)
 
 
+JSONType = Union[None, bool, float, str, list, Dict[str, Any]]
+
+
 class InliningResolver(jsonschema.RefResolver):
     """Inlines resolved schemas."""
 
@@ -58,7 +62,7 @@ class InliningResolver(jsonschema.RefResolver):
         pass
 
     # pylint: disable=function-redefined
-    def resolve_all(self, item: Union[Dict[str, Any], List], recursion_level: int = 0) -> Union[Dict[str, Any], List]:
+    def resolve_all(self, item: JSONType, recursion_level: int = 0) -> JSONType:
         """Recursively resolve all references in the given object."""
         if recursion_level > RECURSION_DEPTH_LIMIT:
             return item
@@ -66,12 +70,15 @@ class InliningResolver(jsonschema.RefResolver):
             ref = item.get("$ref")
             if ref is not None and isinstance(ref, str):
                 with self.resolving(ref) as resolved:
-                    return self.resolve_all(resolved, recursion_level + 1)
-            item = deepcopy(item)
-            for key, sub_item in item.items():
-                item[key] = self.resolve_all(sub_item, recursion_level)
-        elif isinstance(item, list):
-            item = [self.resolve_all(sub_item, recursion_level) for sub_item in deepcopy(item)]
+                    # If the next level of recursion exceeds the limit, then we need to copy it explicitly
+                    # In other cases, this method create new objects for mutable types (dict & list)
+                    next_recursion_level = recursion_level + 1
+                    if next_recursion_level > RECURSION_DEPTH_LIMIT:
+                        return deepcopy(resolved)
+                    return self.resolve_all(resolved, next_recursion_level)
+            return {key: self.resolve_all(sub_item, recursion_level) for key, sub_item in item.items()}
+        if isinstance(item, list):
+            return [self.resolve_all(sub_item, recursion_level) for sub_item in item]
         return item
 
     def resolve_in_scope(self, definition: Dict[str, Any], scope: str) -> Tuple[List[str], Dict[str, Any]]:
@@ -79,8 +86,11 @@ class InliningResolver(jsonschema.RefResolver):
         # if there is `$ref` then we have a scope change that should be used during validation later to
         # resolve nested references correctly
         if "$ref" in definition:
-            with self.in_scope(scope):
+            self.push_scope(scope)
+            try:
                 new_scope, definition = deepcopy(self.resolve(definition["$ref"]))
+            finally:
+                self.pop_scope()
             scopes.append(new_scope)
         return scopes, definition
 
@@ -92,11 +102,14 @@ class ConvertingResolver(InliningResolver):
     This approach is the simplest one, since this logic isolated in a single place.
     """
 
-    def __init__(self, *args: Any, nullable_name: Any, **kwargs: Any) -> None:
+    def __init__(self, *args: Any, nullable_name: Any, is_response_schema: bool = False, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
         self.nullable_name = nullable_name
+        self.is_response_schema = is_response_schema
 
     def resolve(self, ref: str) -> Tuple[str, Any]:
         url, document = super().resolve(ref)
-        document = to_json_schema_recursive(document, nullable_name=self.nullable_name)
+        document = to_json_schema_recursive(
+            document, nullable_name=self.nullable_name, is_response_schema=self.is_response_schema
+        )
         return url, document
